@@ -29,7 +29,7 @@ from nctoolkit.session import (
     remove_protected,
     append_tempdirs,
 )
-from nctoolkit.session import nc_safe_par, temp_dirs, nc_protected, temp_dirs_par
+from nctoolkit.session import nc_safe_par, temp_dirs, temp_dirs_par
 from nctoolkit.show import (
     nc_variables,
     nc_years,
@@ -151,7 +151,7 @@ def options(**kwargs):
         if type(kwargs[key]) is not bool:
             if key == "temp_dir":
                 if type(kwargs[key]) is str:
-                    if os.path.exists(kwargs[key]) == False:
+                    if os.path.exists(kwargs[key]) is False:
                         raise ValueError("The temp_dir specified does not exist!")
                     session_info[key] = os.path.abspath(kwargs[key])
                     session_info["user_dir"] = True
@@ -195,7 +195,7 @@ def options(**kwargs):
                         nc_protected_par.append(ff)
                         nc_protected.remove(ff)
 
-            if (kwargs[key] == False) and key == "parallel":
+            if (kwargs[key] is False) and key == "parallel":
 
                 if len(temp_dirs_par) > 0:
                     for ff in temp_dirs_par:
@@ -290,7 +290,7 @@ if config_file is not None:
 
         if key == "temp_dir":
             if type(value) is str:
-                if os.path.exists(value) == False:
+                if os.path.exists(value) is False:
                     raise ValueError(
                         f"The temp_dir specified by {config_file} does not exist: {value}"
                     )
@@ -388,6 +388,41 @@ def from_xarray(ds):
     d = DataSet(ff)
     return d
 
+def open_geotiff(x = []):
+    """
+    Read geotiff and convert to nctoolkit dataset
+
+    Parameters
+    ---------------
+    x : str or list
+        A string or list of geotiff files or a single url.
+        This requires rioxarray to be installed.
+
+    Returns
+    ---------------
+    open_data : nctoolkit.DataSet
+    """
+
+    if type(x) is str:
+        x = [x]
+
+    if type(x) is not list:
+        raise ValueError("List of str was not supplied!")
+
+    try:
+        import rioxarray
+    except:
+        raise ValueError("This requires rioxarray to be installed")
+
+    ds = open_data()
+    if len(x) > 0:
+        for ff in x:
+            raster = rioxarray.open_rasterio(ff)
+            out_file = temp_file() + "nc"
+            raster.rio.to_raster(out_file)
+            ds.append(out_file)
+    return ds
+
 
 def open_data(x=[], checks=True, **kwargs):
     """
@@ -430,11 +465,6 @@ def open_data(x=[], checks=True, **kwargs):
     >>> ds = nc.open_data("data/*.nc")
 
     """
-    # from nctoolkit.temp_file import temp_file
-
-    if type(x) is str:
-        if x.endswith("*.nc"):
-            x = glob.glob(x)
 
     thredds = False
 
@@ -456,6 +486,13 @@ def open_data(x=[], checks=True, **kwargs):
         if key == "source":
             source = kwargs[key]
 
+    if type(x) is str and thredds is False:
+        if is_url(x) is False:
+            x = glob.glob(x)
+            if len(x) == 0:
+                raise FileNotFoundError("Please provide files that exist")
+
+
     # make sure data has been supplied
     if x is None:
         raise ValueError("No data was supplied!")
@@ -479,7 +516,6 @@ def open_data(x=[], checks=True, **kwargs):
         stop_time = min(file_stop, stop_time)
 
     if type(x) is str:
-        ##if os.path.exists(x) is False:
         if source != "file" or os.path.exists(x) is False:
 
             if is_url(x):
@@ -496,11 +532,9 @@ def open_data(x=[], checks=True, **kwargs):
 
                     start = time.time()
 
-                    i = 0
-
                     search = True
                     while search:
-                        if os.path.exists(new_x) == False:
+                        if os.path.exists(new_x) is False:
                             try:
                                 # work out if there is a time limit for individual files
                                 if stop_time != 10000000000000000000000000000000000:
@@ -521,7 +555,7 @@ def open_data(x=[], checks=True, **kwargs):
                             end = time.time()
                             if (end - start) > wait:
                                 break
-                    if os.path.exists(new_x) == False:
+                    if os.path.exists(new_x) is False:
                         raise ValueError(f"Could not download {x}")
 
                     x = new_x
@@ -581,7 +615,7 @@ def open_data(x=[], checks=True, **kwargs):
 
             for ff in x:
 
-                if is_url(ff) == False:
+                if is_url(ff) is False:
                     raise ValueError(f"{x} is not a url")
 
             new_files = []
@@ -601,11 +635,9 @@ def open_data(x=[], checks=True, **kwargs):
 
                         start = time.time()
 
-                        i = 0
-
                         search = True
                         while search:
-                            if os.path.exists(new_x) == False:
+                            if os.path.exists(new_x) is False:
                                 try:
                                     # work out if there is a time limit for individual files
                                     if stop_time != 10000000000000000000000000000000000:
@@ -626,7 +658,7 @@ def open_data(x=[], checks=True, **kwargs):
                                 end = time.time()
                                 if (end - start) > wait:
                                     break
-                        if os.path.exists(new_x) == False:
+                        if os.path.exists(new_x) is False:
                             raise ValueError(f"Could not download {x}")
 
                         new_files.append(new_x)
@@ -980,22 +1012,32 @@ class DataSet(object):
             yield ff
         return
 
+
     def __repr__(self):
-        current = str(len(self)) + " member ensemble"
+        current = str(len(self))
 
-        variables = []
-        for ff in self:
-            for vv in nc_variables(ff):
-                if vv not in variables:
-                    variables.append(vv)
+        output =  (
+            "<nctoolkit.DataSet>:\nNumber of files: "
+            + current)
+        output = output + "\n" + "File contents:"
+        #repr_params = fmt.get_dataframe_repr_params()
+        output += "\n"
+        output +=  self.show_contents(min(12, len(self))).to_string()
+        output += "\n"
+        if len(self) > 12:
+            output += "......"
+        return output
 
-        return (
-            "<nctoolkit.DataSet>:\nFiles: "
-            + current
-            + "\n"
-            + "Variables: "
-            + str_flatten(variables)
-        )
+        #return(self.show_contents(min(12, len(self))))
+        #''    print(".......")
+
+        #return (
+        #    "<nctoolkit.DataSet>:\nFiles: "
+        #    + current
+        #    + "\n"
+        #    + "Variables: "
+        #    + str_flatten(variables)
+        #)
 
     @property
     def size(self):
@@ -1160,6 +1202,189 @@ class DataSet(object):
 
         return all_years
 
+    def show_contents(self, n = None):
+        """
+        Detailed list of variables contained in a dataset.
+        This will only display the variables in the first file of an ensemble.
+        """
+
+        if n is None:
+            n = len(self)
+
+        list_contents = []
+
+        use_names = True
+
+        for ff in self:
+            if "nctoolkit" in ff:
+                use_names = False
+
+        for ff in self[0:n]:
+
+            dataset = Dataset(ff)
+
+            out = subprocess.run(
+                "cdo sinfon " + ff,
+                shell=True,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+            )
+            if "Unsupported file structure" in str(out.stderr):
+                for ff in self:
+                    remove_safe(ff)
+                    remove_protected(ff)
+                raise ValueError("Unsupported file structure")
+            if "expandWildCards" in out.stderr.decode("utf-8"):
+                for ff in self:
+                    remove_safe(ff)
+                    remove_protected(ff)
+                raise ValueError(out.stderr.decode("utf-8"))
+            out = out.stdout.decode("utf-8")
+            out = out.split("\n")
+            out_inc = ["Grid coordinates :" in ff for ff in out]
+            var_det = []
+            i = 1
+            while True:
+                if out_inc[i]:
+                    break
+                i += 1
+                var_det.append(out[i - 1])
+
+            def split_var(x):
+                x = x.replace(":", "").split(" ")
+                x = [x for x in x if len(x) > 0]
+                new_x = []
+                include = False
+                for y in x[1:]:
+                    if y.isnumeric():
+                        include = True
+
+                    if include:
+                        new_x.append(y)
+                return new_x
+
+            def fix_head(x):
+                x = (
+                    x.replace(":", "")
+                    .replace("  ", " ")
+                    .replace("Parameter name", "variable")
+                )
+                x = x[x.find("Level") :].replace("  ", " ")
+                return x.split(" ")
+
+            def fix_type(x):
+                position = [m.start() for m in re.finditer(":", x)][-1]
+
+                return (
+                    x[: (position - 4)]
+                    + x[(position - 4) : position].replace(" ", "")
+                    + " "
+                    + x[(position):]
+                )
+
+            var_det[0] = fix_head(var_det[0])
+            for ii in range(1, len(var_det)):
+                var_det[ii] = fix_type(var_det[ii])
+                var_det[ii] = split_var(var_det[ii])
+
+            df = pd.DataFrame.from_records(var_det[1:], columns=var_det[0])
+            df = df.loc[:, ["Levels", "Points", "variable", "Dtype"]]
+            df = df.rename(
+                columns={"Levels": "nlevels", "Points": "npoints", "Dtype": "data_type"}
+            )
+
+            longs = None
+            units = None
+            longs = []
+
+            cdo_result = list(df.variable)
+
+            for x in cdo_result:
+                try:
+                    longs.append(dataset.variables[x].long_name)
+                except:
+                    longs.append(None)
+            units = []
+            for x in cdo_result:
+                try:
+                    units.append(dataset.variables[x].units)
+                except:
+                    units.append(None)
+
+            df = pd.DataFrame({"variable": cdo_result}).merge(df)
+
+            if longs is not None:
+                df["long_name"] = longs
+            if units is not None:
+                df["unit"] = units
+
+            df = df.assign(nlevels=lambda x: x.nlevels.astype("int")).assign(
+                npoints=lambda x: x.npoints.astype("int")
+            )
+
+            times = []
+
+            ds = xr.open_dataset(ff, decode_times=False)
+            time_name = [x for x in ds.variables if "time" in x]
+
+            # get time name
+
+            if len(time_name) > 0:
+                time_name = time_name[0]
+            else:
+                time_name = "time"
+
+            for vv in cdo_result:
+                done = False
+                try:
+                    ds_times = ds[vv][time_name].values
+                except:
+                    times.append(None)
+                    done = True
+
+                if done is False:
+                    try:
+                        n_times = len(ds_times)
+                    except:
+                        n_times = 1
+                    times.append(n_times)
+
+            df["ntimes"] = times
+
+            df = df.loc[
+                :,
+                [
+                    "variable",
+                    "ntimes",
+                    "npoints",
+                    "nlevels",
+                    "long_name",
+                    "unit",
+                    "data_type",
+                ],
+            ]
+            list_contents.append(df.assign(file=ff))
+
+        if len(list_contents) == 1:
+            return list_contents[0].drop(columns="file")
+
+        if use_names is False:
+            new_df = []
+            i = 1
+            for x in list_contents:
+                new_df.append(x.assign(file=f"file {i}"))
+                i += 1
+
+            new_df = pd.concat(new_df)
+
+            if len(set(new_df.file)) == 1:
+                return new_df.drop(columns="file")
+            else:
+                new_df = new_df.set_index("file")
+                return new_df
+        else:
+            return pd.concat(list_contents).set_index("file")
+
     @property
     def contents(self):
         """
@@ -1167,6 +1392,8 @@ class DataSet(object):
         This will only display the variables in the first file of an ensemble.
         """
 
+        return self.show_contents()
+
         list_contents = []
 
         use_names = True
@@ -1280,7 +1507,7 @@ class DataSet(object):
 
             times = []
 
-            ds = xr.open_dataset(ff, decode_times = False)
+            ds = xr.open_dataset(ff, decode_times=False)
             time_name = [x for x in ds.variables if "time" in x]
 
             # get time name
@@ -1324,7 +1551,7 @@ class DataSet(object):
         if len(list_contents) == 1:
             return list_contents[0].drop(columns="file")
 
-        if use_names == False:
+        if use_names is False:
             new_df = []
             i = 1
             for x in list_contents:
@@ -1390,6 +1617,7 @@ class DataSet(object):
     def copy(self):
         """
         Make a deep copy of an DataSet object
+        Note: This will not make disk copies of the temporary files underlying datasets, so it will be disk-space efficient.
         """
         self.run()
 
@@ -1427,6 +1655,7 @@ class DataSet(object):
     from nctoolkit.add_etc import power
     from nctoolkit.add_etc import square
     from nctoolkit.add_etc import sqrt
+    from nctoolkit.add_etc import day_stat
 
     from nctoolkit.anomaly import annual_anomaly
     from nctoolkit.anomaly import monthly_anomaly
@@ -1442,6 +1671,7 @@ class DataSet(object):
     from nctoolkit.centres import centre
 
     from nctoolkit.checks import check
+    from nctoolkit.checks import is_corrupt
 
     from nctoolkit.cleanup import disk_clean
 
@@ -1470,7 +1700,9 @@ class DataSet(object):
     from nctoolkit.ensembles import ensemble_percentile
 
     from nctoolkit.esoteric import assign_coords
+    from nctoolkit.esoteric import fix_nemo_ersem_grid
     from nctoolkit.esoteric import set_gridtype
+    from nctoolkit.esoteric import no_leaps
 
     from nctoolkit.fill import fill_na
 
@@ -1533,6 +1765,7 @@ class DataSet(object):
     from nctoolkit.select import select
 
     from nctoolkit.setters import set_date
+    from nctoolkit.setters import set_year
     from nctoolkit.setters import set_missing
     from nctoolkit.setters import set_units
     from nctoolkit.setters import set_longnames
@@ -1552,7 +1785,6 @@ class DataSet(object):
     from nctoolkit.temporal_stat import tmin
     from nctoolkit.temporal_stat import trange
     from nctoolkit.temporal_stat import tvar
-    from nctoolkit.temporal_stat import tvariance
     from nctoolkit.temporal_stat import tstdev
     from nctoolkit.temporal_stat import tsum
     from nctoolkit.temporal_stat import tcumsum
@@ -1582,6 +1814,7 @@ class DataSet(object):
     from nctoolkit.verticals import vertical_interp
     from nctoolkit.verticals import bottom
     from nctoolkit.verticals import bottom_mask
+    from nctoolkit.verticals import surface_mask
     from nctoolkit.verticals import invert_levels
 
     from nctoolkit.zip import zip
@@ -1592,5 +1825,3 @@ class DataSet(object):
     from nctoolkit.zonals import zonal_range
 
     # Deprecated methods
-    from nctoolkit.deprecated import merge_time
-    from nctoolkit.deprecated import surface
