@@ -1,14 +1,10 @@
 import warnings
 from datetime import datetime, timedelta
-import copy
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.session import nc_safe, session_info, append_safe, remove_safe
-from nctoolkit.temp_file import temp_file
 from nctoolkit.runthis import run_this
-from nctoolkit.show import nc_years, nc_times
-from nctoolkit.crop import crop
+from nctoolkit.show import nc_years
 
 
 def to_date(x):
@@ -84,6 +80,46 @@ def select_seasons(self, season=None):
     run_this(cdo_command, self, output="ensemble")
 
 
+def select_days(self, days=None):
+    """
+    Select days from a dataset
+    This method will subset the dataset to only contain days within the list given.
+    A warning message will be provided when there are missing days.
+
+    Parameters
+    -------------
+    days : list, range or int
+        Month(s) to select.
+    """
+
+    if days is None:
+        raise ValueError("Please supply days")
+
+    # check validity of days
+    if type(days) is range:
+        days = list(days)
+
+    if type(days) is not list:
+        days = [days]
+    # all of the variables in days need to be converted to ints,
+    # just in case floats have been provided
+    # coerce to int if numpy float etc.
+
+    days = [int(x) if "int" in str(type(x)) else x for x in days]
+
+
+    for x in days:
+        if type(x) is not int:
+            raise TypeError(f"{x} is not an int")
+        if x not in list(range(1, 32)):
+            raise ValueError(f"{x} is not a day")
+
+    days = str_flatten(days, ",")
+
+    cdo_command = f"cdo -selday,{days}"
+    run_this(cdo_command, self, output="ensemble")
+
+
 def select_months(self, months=None):
     """
     Select months from a dataset
@@ -107,6 +143,10 @@ def select_months(self, months=None):
         months = [months]
     # all of the variables in months need to be converted to ints,
     # just in case floats have been provided
+    # coerce to int if numpy float etc.
+
+    months = [int(x) if "int" in str(type(x)) else x for x in months]
+
 
     for x in months:
         if type(x) is not int:
@@ -141,6 +181,7 @@ def select_years(self, years=None):
         years = [years]
 
     # convert years to int
+    years = [int(x) if "int" in str(type(x)) else x for x in years]
 
     for yy in years:
         if type(yy) is not int:
@@ -288,6 +329,8 @@ def select(self, **kwargs):
         So using 'var*' would select all variables beginning with 'var'.
     seasons : str
         Seasons to select. One of "DJF", "MAM", "JJA", "SON".
+    days : list, range or int
+        Days(s) to select.
     months : list, range or int
         Month(s) to select.
     years : list,range or int
@@ -333,29 +376,33 @@ def select(self, **kwargs):
 
     for key in kwargs:
 
-        if "ran" in key and non_selected:
+        if "ran" in key:
             select_period(self, kwargs[key])
             non_selected = False
 
-        if "var" in key and non_selected:
+        if "var" in key:
             select_variables(self, kwargs[key])
             non_selected = False
 
-        if "mon" in key and non_selected:
+        if "mon" in key:
             select_months(self, kwargs[key])
             non_selected = False
 
-        if "year" in key and non_selected:
+        if "year" in key:
             select_years(self, kwargs[key])
             non_selected = False
 
-        if "seas" in key and non_selected:
+        if "seas" in key:
             select_seasons(self, kwargs[key])
             non_selected = False
 
-        if "time" in key and non_selected:
+        if "time" in key:
             select_timesteps(self, kwargs[key])
             non_selected = False
 
+        if "day" in key:
+            select_days(self, kwargs[key])
+            non_selected = False
+
     if non_selected:
         raise AttributeError(f"{key} is not a valid select method")
