@@ -3,8 +3,7 @@ import copy
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_this, run_cdo
-from nctoolkit.session import nc_safe, remove_safe
-import warnings
+from nctoolkit.session import remove_safe
 
 
 def to_nc(self, out, zip=True, overwrite=False):
@@ -43,13 +42,9 @@ def to_nc(self, out, zip=True, overwrite=False):
 
     if os.path.basename(out) != out:
         out_dir = os.path.dirname(out)
-        if os.path.exists(out_dir) == False:
+        if os.path.exists(out_dir) is False:
             raise ValueError(f"{out_dir} does not exist!")
 
-    # If you are trying to overwrite a file in self.current, cdo cannot simultaneously have it opened and written to
-    if out in self and (overwrite is True):
-        self.run()
-
     ff = copy.deepcopy(self.current)
 
     # Figure out if it is possible to write the file, i.e. if a dataset is still an
